#######################
Developer documentation
#######################

dfVFS uses a development process similar to that of Plaso, therefore see
`Plaso's Developers Guide <https://plaso.readthedocs.io/en/latest/sources/developer/Developers-Guide.html>`__.

.. toctree::
   :maxdepth: 2

   Internals <Internals>
   Helpers <Helpers>
   Adding a new VFS type <Adding-new-type>
   Testing <Testing>
